@@ -28,6 +28,12 @@ class TestUtils(object):
         decode_task(encode_task(TASK))
         eq_(orig, TASK)
 
+    def test_with_escaped_quotes(self):
+        expected = {'this': r'has a \"quote\" in it.'}
+        line = r'[this:"has a \"quote\" in it."]'
+        r = decode_task(line)
+        eq_(r, expected)
+
     def test_decode(self):
         r = decode_task(encode_task(TASK))
         eq_(r, TASK)
